@@ -1,4 +1,4 @@
-from typing import Any, List, Optional, cast
+from typing import Any, List, Optional
 
 from rapidfuzz import fuzz
 
@@ -32,11 +32,19 @@ class ScoreCalculator:
                 total_score=0.0,
             )
         # Get the average match score as "final score" result
-        #   w/ high confidence w/ match score >= 80.0
+        # AND we're not penalizing the total match score,
+        #  by excluding those rules that have 0 match scores when calculating the final match score,
+        #  meaning the required data attributes/fields in the rule are not available or absent.
         final_score: float = 0
         for match_result in match_results:
-            final_score += cast(float, match_result.rule_score or 0)
-        final_score /= len(match_results)
+            final_score += match_result.rule_score
+
+        number_of_rules_with_present_attributes: int = (
+            ScoreCalculator.get_number_of_rules_with_present_attributes(match_results)
+        )
+
+        final_score /= number_of_rules_with_present_attributes
+
         return MatchScoreWithoutThreshold(
             id_source=source.id_,
             id_target=target.id_,
@@ -44,6 +52,33 @@ class ScoreCalculator:
             total_score=final_score,
         )
 
+    @staticmethod
+    def get_number_of_rules_with_present_attributes(results: List[RuleScore]) -> int:
+        number_of_rules_with_present_attributes: int = sum(
+            map(
+                lambda result: any(
+                    list(
+                        filter(
+                            lambda rule_attribute_score: getattr(
+                                rule_attribute_score, "present"
+                            )
+                            is True,
+                            result.attribute_scores,
+                        )
+                    )
+                )
+                is True,
+                results,
+            )
+        )
+        number_of_rules_with_present_attributes = (
+            1
+            if number_of_rules_with_present_attributes == 0
+            else number_of_rules_with_present_attributes
+        )
+
+        return number_of_rules_with_present_attributes
+
     @staticmethod
     def calculate_score(
         rules: List[Rule], source: ScoringInput, target: ScoringInput
