@@ -71,13 +71,16 @@ class Matcher:
     def match(
         self,
         *,
-        source_json: str,
-        target_json: str,
+        source_json: Union[str, List[str]],
+        target_json: Union[str, List[str]],
         threshold: float = 80.0,
         verbose: bool = False,
     ) -> List[MatchScore]:
         assert source_json
+        assert isinstance(source_json, str) or isinstance(source_json, list)
         assert target_json
+        assert isinstance(target_json, str) or isinstance(target_json, list)
+
         source: List[ScoringInput] = FhirLoader.get_scoring_inputs(
             resource_json=source_json
         )
